==> intercom-sdk-base-3.1.0-sources.jar: io/intercom/android/sdk/push/IntercomPushBroadcastReceiver.java <==
package io.intercom.android.sdk.push;

import android.app.Application;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;

import io.intercom.android.sdk.Injector;
import io.intercom.android.sdk.api.Api;
import io.intercom.android.sdk.identity.UserIdentity;
import io.intercom.android.sdk.metrics.MetricFactory;
import io.intercom.android.sdk.metrics.MetricsStore;

public class IntercomPushBroadcastReceiver extends BroadcastReceiver {
    static final String INTERCOM_PUSH_OPENED = "io.intercom.android.sdk.INTERCOM_PUSH_OPENED";
    static final String INTERCOM_PUSH_DISMISSED = "io.intercom.android.sdk.INTERCOM_PUSH_DISMISSED";

    private final PushReceiverDelegate pushReceiverDelegate = new PushReceiverDelegate();

    @Override public void onReceive(Context context, Intent intent) {
        Injector.init((Application) context.getApplicationContext());
        Injector injector = Injector.get();
        UserIdentity userIdentity = injector.getUserIdentity();
        MetricFactory metricFactory = new MetricFactory(userIdentity);
        MetricsStore metricStore = injector.getMetricsStore();

        switch (intent.getAction()) {
            case INTERCOM_PUSH_DISMISSED:
                pushReceiverDelegate.trackDismiss(intent, userIdentity, metricStore, metricFactory);
                break;
            default:
            case INTERCOM_PUSH_OPENED:
                Api api = injector.getApi();
                pushReceiverDelegate.handlePushTap(context, intent, api, userIdentity, metricStore, metricFactory);
                break;
        }
    }

}

==> intercom-sdk-base-3.1.4-sources.jar: io/intercom/android/sdk/push/IntercomPushBroadcastReceiver.java <==
package io.intercom.android.sdk.push;

import android.app.Application;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;

import com.intercom.twig.Twig;

import io.intercom.android.sdk.Injector;
import io.intercom.android.sdk.api.Api;
import io.intercom.android.sdk.identity.UserIdentity;
import io.intercom.android.sdk.logger.LumberMill;
import io.intercom.android.sdk.metrics.MetricTracker;

public class IntercomPushBroadcastReceiver extends BroadcastReceiver {
    static final String INTERCOM_PUSH_OPENED = "io.intercom.android.sdk.INTERCOM_PUSH_OPENED";
    static final String INTERCOM_PUSH_DISMISSED = "io.intercom.android.sdk.INTERCOM_PUSH_DISMISSED";
    private static final Twig TWIG = LumberMill.getLogger();

    private final PushReceiverDelegate pushReceiverDelegate = new PushReceiverDelegate();

    @Override public void onReceive(Context context, Intent intent) {
        Injector.initIfCachedCredentials((Application) context.getApplicationContext());
        Injector injector = Injector.get();

        if (injector == null) {
            TWIG.w("Push not handled because Intercom is not initialised");
            return;
        }

        UserIdentity userIdentity = injector.getUserIdentity();
        MetricTracker metricTracker = injector.getMetricTracker();

        switch (intent.getAction()) {
            case INTERCOM_PUSH_DISMISSED:
                pushReceiverDelegate.trackDismiss(intent, userIdentity, metricTracker);
                break;
            default:
            case INTERCOM_PUSH_OPENED:
                Api api = injector.getApi();
                pushReceiverDelegate.handlePushTap(context, intent, api, userIdentity, metricTracker);
                break;
        }
    }

}
